﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using UserManagement;

namespace UserManagementGUI
{
    public partial class Form1 : Form, IUserView
    {
        UserController controller;
        DataAccess dataAccess;

        public Form1()
        {
            dataAccess = new DataAccess();
            controller = new UserController(this, dataAccess);
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            DepartmentList.DataSource = UserManagement.User.ValidDepartments;
        }

        private void cmdSave_Click(object sender, EventArgs e)
        {
            UserSubmitted(this);
        }

        private void Field_Leave(object sender, EventArgs e)
        {
            ErrorMessages.Text = String.Empty;
            FieldEntered(this, GetNameFromControlName(sender));
        }

        private string GetNameFromControlName(object sender)
        {
            string controlName = ((Control)sender).Name;
            switch (controlName)
            {
                case "FirstNameText":
                    return "FirstName";
                case "LastNameText":
                    return "LastName";
                case "DateOfBirthPicker":
                    return "DateOfBirth";
                case "DepartmentList":
                    return "Department";
            }
            throw new ArgumentOutOfRangeException();
        }

        #region IUserView Members

        public event FieldEnteredDelegate FieldEntered;

        public event UserSubmittedDelegate UserSubmitted;

        public void InvalidField(string fieldName, string message)
        {
            ErrorMessages.Text = "Invalid field: " + fieldName;
        }

        public string FirstName
        {
            get { return FirstNameText.Text; }
        }

        public string LastName
        {
            get { return LastNameText.Text; }
        }

        public DateTime DateOfBirth
        {
            get { return DateOfBirthPicker.Value; }
        }

        public string Department
        {
            get { return DepartmentList.SelectedValue.ToString(); }
        }

        #endregion
    }
}
