﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using NUnit.Framework;
using UserManagement;

namespace UserManagementTests
{
    [TestFixture]
    public class UserTests
    {
        [Test]
        public void UserShouldNotAllowFirstNameToBeNull()
        {
            try
            {
                User user = new User();
                user.FirstName = null;
            }
            catch (ArgumentNullException ex)
            {
                Assert.IsTrue(true);
                return;
            }
            Assert.Fail("User should not allow FirstName to be null");
        }

        [Test]
        public void UserShouldNotAllowLastNameToBeNull()
        {
            try
            {
                User user = new User();
                user.LastName = null;
            }
            catch (ArgumentNullException ex)
            {
                Assert.IsTrue(true);
                return;
            }
            Assert.Fail("User should not allow LastName to be null");
        }

        [Test]
        public void UserShouldNotAllowFirstNameToBeEmpty()
        {
            try
            {
                User user = new User();
                user.FirstName = String.Empty;
            }
            catch (ArgumentNullException ex)
            {
                Assert.IsTrue(true);
                return;
            }
            Assert.Fail("User should not allow FirstName to be null");
        }

        [Test]
        public void UserShouldNotAllowLastNameToBeEmpty()
        {
            try
            {
                User user = new User();
                user.LastName = String.Empty;
            }
            catch (ArgumentNullException ex)
            {
                Assert.IsTrue(true);
                return;
            }
            Assert.Fail("User should not allow LastName to be null");
        }

        [Test]
        public void UserShouldNotAllowDateOfBirthToBeAfterToday()
        {
            try
            {
                User user = new User();
                DateTime tomorrow = DateTime.Now.AddDays(1);
                user.DateOfBirth = tomorrow;
            }
            catch (ArgumentOutOfRangeException ex)
            {
                Assert.IsTrue(true);
                return;
            }
            Assert.Fail("User should not allow LastName to be null");
        }

        [Test]
        public void UserShouldAllowSettingOfDateOfBirthBeforeToday()
        {
            User user = new User();
            DateTime yesterday = DateTime.Now.AddDays(-1);
            user.DateOfBirth = yesterday;
            Assert.IsTrue(true);
        }

        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void UserShouldNotAllowDateOfBirthOfToday()
        {
            User user = new User();
            user.DateOfBirth = DateTime.Now;
        }

        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void UserShouldNotAllowInvalidDepartment()
        {
            User user = new User();
            user.Department = "alkhdsadhsa";
        }
    }
}
